local MinBuild, MaxBuild, Build = 40000, 0, select(4, GetBuildInfo())
if Build < MinBuild or ( MaxBuild > 0 and Build > MaxBuild ) then return end
local AddonName, a = ...
local AddonTitle = select(2, GetAddOnInfo(AddonName))
local PlainAddonTitle = AddonTitle:gsub("|c........", ""):gsub("|r", "")
local L = a.Localize
local s = SpellFlashAddon
local x = SpellFlashAddon.UpdatedVariables

local function SetColor(UseColor, Color, ElseColor)
	if UseColor then
		return Color
	end
	return ElseColor or "Pink"
end

--[[
	White - Default
	Yellow - Limited Time or No Global Cooldown
	Purple - AOE or Positional Damage
	Blue - AOE Debuff
	Orange - Finishing Move
	Aqua - Spell Interrupt, Reflect or Dispel
	Green - Self Buff or Turn Autocast On
	Red - Emergency Mitigation Cooldowns or Turn Autocast Off
	Pink - Optional
]]

-- SpellFlash API: http://wow.curseforge.com/addons/spellflash/pages/api/
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff


local function Buffs()
	if a.GetConfig("Disable_Buff") then return end
	if not IsMounted() or s.InCombat() then
		if s.Flashable(588--[[Inner Fire]]) and a.Castable["Inner Fire"]() then
			s.Flash(588--[[Inner Fire]], "Green")
		end
		if s.Flashable(73413--[[Inner Will]]) and a.Castable["Inner Will"]() then
			s.Flash(73413--[[Inner Will]], "Green")
		end
		if s.Flashable(21562--[[Power Word: Fortitude]]) and a.Castable["Power Word: Fortitude"]() then
			s.Flash(21562--[[Power Word: Fortitude]], "Green")
		end
		if s.Flashable(27683--[[Shadow Protection]]) and a.Castable["Shadow Protection"]() then
			s.Flash(27683--[[Shadow Protection]], "Green")
		end
		if s.Flashable(15286--[[Vampiric Embrace]]) and a.Castable["Vampiric Embrace"]() then
			s.Flash(15286--[[Vampiric Embrace]], "Green")
		end
		if s.Flashable(47585--[[Dispersion]]) and not s.InCombat() and s.PowerPercent("player") < 60 and a.Castable["Dispersion"]()then
			s.Flash(47585--[[Dispersion]], "Green")
		end
	end
end

local function CrowdControl()
	if a.GetConfig("Disable_CC") then return end
	if s.Flashable(9484--[[Shackle Undead]]) and a.Castable["Shackle Undead"]() then
		s.Flash(9484--[[Shackle Undead]], SetColor(x.ActiveEnemy, "Purple"))
	end
end

local function LightWell8Ball()
	if a.GetConfig("Disable_LW8B") then return end
	
	EightBall = {};

EightBall.FontColor = "|cFFFFCC66";
EightBall.ChatHeader = EightBall.FontColor.."[Lightwell]|r";
EightBall.AutoReply = 0;
EightBall.YesNo = {
  "do",
  "done",
  "dont",
  "doing",
  "did",
  "didnt",
  "does",
  "doesnt",
  "has",
  "hasnt",
  "have",
  "havent",
  "can",
  "cant",
  "could",
  "couldnt",
  "may",
  "might",
  "must",
  "will",
  "wont",
  "would",
  "wouldnt",
  "shall",
  "should",
  "shouldnt",
  "is",
  "isnt",
  "am",  -- am i
  "are",  -- are we
  "arent",
  "any",
  "anything",
  "was",
  "wasnt",
  "ever seen",
  "ever see",
};
EightBall.NonYesNo = {
  "who",
  "whos",
  "what",
  "whats",
  "when",
  "where",
  "whered",
  "wheres",
  "why",
  "how",
  "hows",
  "%Aor",
  "^or",
  "which",
};
EightBall.Exception = {
  "is that how",
  "is this how",
  "is that why",
  "is this why",
  "is that where",
  "is this where",
  "is that what",
  "is this what",
  "is that who",
  "is this who",
  "is that when",
  "is this when",
};

function EightBall:GetSaying()
  local randnum = random(20);
  local saying = {
    "Signs point to yes.",
    "Yes.",
    "Most likely.",
    "Without a doubt.",
    "Yes - definately.",
    "As I see it, yes.",
    "You may rely on it.",
    "Outlook good.",
    "It is certain.",
    "It is decidedly so.",
    "Reply hazy, try again.",
    "Better not tell you now.",
    "Ask again later.",
    "Concentrate and ask again.",
    "Cannot predict now.",
    "My sources say no.",
    "Very doubtful.",
    "My reply is no.",
    "Outlook not so good.",
    "Don't count on it.",
  };
    return saying[randnum];
end

function EightBall:GetStatus(arg)
  if ( arg == 1 ) then
    return "|cFF00FF00On|r";
  elseif ( arg == 0 ) then
    return "|cFFFF0000Off|r";
  elseif ( arg == "" ) then
    return "|cFF777777Disabled|r";
  else
    return "|cFF00FF00"..arg.."|r";
  end
end

function EightBall:SlashCmdHandler(msg)
  msg = string.lower(msg);
  local chattype, chan;
  local a,b,cmd,arg = string.find(msg,"(%S+)%s*(%S*)");

  if ( cmd == "emote" ) then
    chattype = "EMOTE";
  elseif ( cmd == "chan" ) then
    if ( GetChannelName(arg) ~= 0 ) then
      chattype = "CHANNEL";
      chan = GetChannelName(arg);
    else
      DEFAULT_CHAT_FRAME:AddMessage(self.ChatHeader.." Usage: /8ball [chan <channel name>]");
    end
  elseif ( cmd == "whisper" ) then
    if ( arg ~= "" ) then
      chattype = "WHISPER";
      chan = arg;
    else
      DEFAULT_CHAT_FRAME:AddMessage(self.ChatHeader.." Usage: /8ball [whisper <name>]");
    end
  elseif ( cmd == "auto" ) then
    if ( arg == "on" ) then
      self.AutoReply = 1;
    elseif ( arg == "off" ) then
      self.AutoReply = 0;
    else
      DEFAULT_CHAT_FRAME:AddMessage(self.ChatHeader.." Usage: /8ball [auto <on/off>]");
    end
    DEFAULT_CHAT_FRAME:AddMessage(self.ChatHeader.." Automatic response set to "..self:GetStatus(self.AutoReply)..".");
  else
    DEFAULT_CHAT_FRAME:AddMessage(self.ChatHeader.." Usage: /8ball [auto | keyword | <output channel>]");
    DEFAULT_CHAT_FRAME:AddMessage(" - "..self.FontColor.."auto:|r ["..self:GetStatus(EightBall.AutoReply).."] Turns on/off automatic replies to yes/no questions");
  end
  if ( chattype ) then
    SendChatMessage("'s Lightwell says: " ..self:GetSaying(), chattype, nil, chan);
  end
end

--[[Function for Yes/No question recognition
The way we are going to do this, is first a score system to check against
words that do not make sense as a yes/no question, and then check for exceptions
to those words.
IE - how is normally a word that would get -5 to the score, since how questions are not yes/no
     However, questions that have 'is this how' or 'is that how' would be a yes/no
Once we score the system, we check for words that would normally make it a yes/no question
Reason we don't add those words to the scoring system, is by the following question example:
which ones are the ones you can root?  (Which -5, Are +5, Can +5) This isn't a yes/no question
Under the scoring system, we would only get Which -5, and then check the words Are and Can seperatly
Since the score is -5, this is an invalid question, and we don't even have to check are/can

For the time being, I am just gonna process until I hit a match for the scoring system]]

function EightBall:OnEvent(Frame, Event, ...)
  local CheckWord, IsAQuestion, chattype, chan, index;
  local score = 0;
  local Arg1, Arg2, _, _, _, _, Arg7, _, Arg9 = ...;

  if ( string.find(Event, "CHAT_MSG") ) then
    if ( Event == "CHAT_MSG_EMOTE" ) then
      if ( Arg7 ~= 0 ) then
        return;
      end
    end
    -- if ( string.lower(Arg2) == string.lower(UnitName("player")) ) then
      -- return;
    -- end
    Arg1 = string.lower(Arg1);
    if ( self.AutoReply ~= 0 and not IsAQuestion ) then
      if ( string.find(Arg1,".+%?") ) then
        -- Remove all apostrophes
        Arg1 = string.gsub(Arg1, "'", "");
        for index, CheckWord in pairs(self.NonYesNo) do
          if ( string.find(Arg1,CheckWord.."%A") ) then
            score = score - 5;
            break;
          end
        end
        for index, CheckWord in pairs(self.Exception) do
          if ( string.find(Arg1,CheckWord) ) then
            score = score + 5;
            break;
          end
        end
        if ( score < 0 ) then
          return;
        end
        for index, CheckWord in pairs(self.YesNo) do
          if ( string.find(Arg1, CheckWord.."%A") ) then
            IsAQuestion = 1;
            break;
          end
        end
      end
    end
    if ( IsAQuestion ) then
      if ( Event == "CHAT_MSG_EMOTE" ) then
        chattype = "EMOTE";
        chan = GetChannelName(Arg9);
      end
      if ( chattype ) then
        SendChatMessage("'s Lightwell says: " ..self:GetSaying(), chattype, nil, chan);
      end
    end
  end
end

SLASH_EIGHTBALL1 = "/eightball";
SLASH_EIGHTBALL2 = "/8ball";
SlashCmdList["EIGHTBALL"] = function(msg) EightBall:SlashCmdHandler(msg) end;

local EightBallFrame = CreateFrame("Frame");
EightBallFrame:SetScript("OnEvent", function(...) EightBall:OnEvent(...) end);
EightBallFrame:RegisterEvent("CHAT_MSG_EMOTE");
EightBallFrame:RegisterEvent("ADDON_LOADED");
	
end

local function Survival()
	if a.GetConfig("Disable_Surv") then return end
	if x.ThreatPercent >= 95 and ( GetNumRaidMembers() > 1 or GetNumPartyMembers() > 0 ) then
		if s.Flashable(586--[[Fade]]) and x.NoCC and a.Castable["Fade"]() then
			s.Flash(586--[[Fade]], SetColor(x.ActiveEnemy, "Purple"))
		end
	end
	if x.ThreatPercent >= 95 then
		if s.Flashable(17--[[Power Word: Shield]]) and a.Castable["Power Word: Shield"]() then
		s.Flash(17--[[Power Word: Shield]], SetColor(x.ActiveEnemy, "Purple"))
		end
	end
	if s.Flashable(17--[[Power Word: Shield]]) and s.HealthPercent("player") < 50 and a.Castable["Power Word: Shield"]() then
		s.Flash(17--[[Power Word: Shield]], SetColor(x.ActiveEnemy, "Red"))
	end
	if s.Flashable(19236--[[Desperate Prayer]]) and s.HealthPercent("player") < 50 and a.Castable["Desperate Prayer"]() then
		s.Flash(19236--[[Desperate Prayer]], SetColor(x.ActiveEnemy, "Red"))
	end
end

local function ManaRegen()
	if a.GetConfig("Disable_Mana") then return end
	if s.TalentMastery(3) then
		if s.Flashable(32379--[[Shadow Word: Death]]) and s.HasTalent(88994--[[Masochism]]) and x.NoCC and s.PowerPercent("player") < 10 and a.Castable["Shadow Word: Death"]() then
			s.Flash(32379--[[Shadow Word: Death]], SetColor(x.ActiveEnemy, "Aqua"))
		elseif s.Boss("target") and s.Debuff(34914--[[Vampiric Touch]]) then
			if s.Flashable(34433--[[Shadowfiend]]) and x.NoCC and a.Castable["Shadowfiend"]() then
				s.Flash(34433--[[Shadowfiend]], SetColor(x.ActiveEnemy, "Yellow"))
			end
		end
	end
	if s.Flashable(34433--[[Shadowfiend]]) and x.NoCC and s.PowerPercent("player") < 20 and a.Castable["Shadowfiend"]() then
		s.Flash(34433--[[Shadowfiend]], SetColor(x.ActiveEnemy, "Green"))
	elseif s.Flashable(47585--[[Dispersion]]) and s.PowerPercent("player") < 20 and a.Castable["Dispersion"]()then
		s.Flash(47585--[[Dispersion]], "Green")
	elseif s.Flashable(47585--[[Dispersion]]) and s.PowerPercent("player") < 50 and s.HealthPercent("player") < 20 and a.Castable["Dispersion"]() then
		s.Flash(47585--[[Dispersion]], "Red")
	end
	if s.Flashable(47585--[[Dispersion]]) and s.CrowedControlled("player") or s.MovementImpaired("player") or s.Debuff(15487--[[Silence]], "player") and a.Castable["Dispersion"]() then
		s.Flash(47585--[[Dispersion]], "Purple")
	end
end

local function Interrupts()
	if a.GetConfig("Disable_Kick") then return end
	if s.Flashable(15487--[[Silence]]) and not s.Boss() and x.NoCC and a.Castable["Silence"]() then
		s.Flash(15487--[[Silence]], SetColor(x.ActiveEnemy, "Aqua"))
	end
end

local function TrashRotation()
	if not a.GetConfig("Enable_Trash") then return end
	if s.TalentMastery(3) then
		if not (s.Boss("target") or s.MyDebuff(34914--[[Vampiric Touch]]) or s.MyDebuff(589--[[Shadow Word: Pain]]) or s.MyDebuff(2944--[[Devouring Plague]])) then
			if s.Flashable(8092--[[Mind Blast]]) and not s.Buff(95799--[[Empowered Shadow]],"player") and s.BuffStack(77487--[[Shadow Orb]], "player") >= 1 and a.Castable["Mind Blast"]() then
				s.Flash(8092--[[Mind Blast]], "Yellow")
			elseif s.Flashable(32379--[[Shadow Word: Death]]) and x.NoCC and s.GetChanneling(15407--[[Mind Flay]], "player") <= 1 and a.Castable["Shadow Word: Death"]() then
				s.Flash(32379--[[Shadow Word: Death]], SetColor(x.ActiveEnemy, "Yellow"))
			elseif s.Flashable(8092--[[Mind Blast]]) and s.MyDebuffStack(73510--[[Mind Spike]], "target") >= 2 and x.NoCC and a.Castable["Mind Blast"]() then
				s.Flash(8092--[[Mind Blast]], SetColor(x.ActiveEnemy, "Yellow"))
			elseif s.Flashable(15407--[[Mind Flay]]) and s.MyDebuffStack(73510--[[Mind Spike]], "target") >= 2 and x.NoCC and a.Castable["Mind Flay"]() then
				s.Flash(15407--[[Mind Flay]], SetColor(x.ActiveEnemy))
			elseif s.Flashable(73510--[[Mind Spike]]) and x.NoCC and a.Castable["Mind Spike"]() then
				s.Flash(73510--[[Mind Spike]], SetColor(x.ActiveEnemy, "Orange"))
			end
		end
	end
end

local function ShadowRotation()
	if a.GetConfig("Disable_Shadow") then return end
	if s.TalentMastery(3) then
			if a.Castable["Shadowform"]() then
				if s.Flashable(15473--[[Shadowform]]) then
					s.Flash(15473--[[Shadowform]])
				end
				s.FlashForm(15473--[[Shadowform]])
			end
			
				if s.Buff(32182--[[Heroism]], "player") or s.Buff(2825--[[Bloodlust]], "player") or s.Buff(80353--[[Time Warp]], "player") then
					if s.Flashable(s.ItemName(58091--[[Volcanic Potion]])) and x.NoCC and a.ItemCastable["Volcanic Potion"]() then
						s.Flash(s.ItemName(58091--[[Volcanic Potion]], SetColor(x.ActiveEnemy, "Green")))
					end
				end
				
				if s.Flashable(8092--[[Mind Blast]]) and x.NoCC and s.HasTalent(14910--[[Mind Melt]]) and s.BuffStack(81292--[[Mind Melt]], "player") == 2 and a.Castable["Mind Blast"]() then
					s.Flash(8092--[[Mind Blast]], SetColor(x.ActiveEnemy))
				end
				
				if s.Flashable(87151--[[Archangel]]) and s.BuffStack(87118--[[Dark Evangelism]], "player") >= 5 and x.NoCC and s.GetChanneling(15407--[[Mind Flay]], "player") <= 1 and a.Castable["Archangel"]() then
					s.Flash(87151--[[Archangel]], SetColor(x.ActiveEnemy, "Red"))
				end
				
				if s.Flashable(8092--[[Mind Blast]]) and s.Buff(95799--[[Empowered Shadow]], "player") and s.BuffStack(77487--[[Shadow Orb]], "player") == 3 and x.NoCC and s.GetChanneling(15407--[[Mind Flay]], "player") <= 1 and a.Castable["Mind Blast"] () then
					s.Flash(8092--[[Mind Blast]], SetColor(x.ActiveEnemy, "Yellow"))
				end
				if not s.Buff(95799--[[Empowered Shadow]], "player", 3) then
					if s.Flashable(8092--[[Mind Blast]]) and s.BuffStack(77487--[[Shadow Orb]], "player") >= 2 and x.NoCC and s.GetChanneling(15407--[[Mind Flay]], "player") <= 1 and a.Castable["Mind Blast"] () then
						s.Flash(8092--[[Mind Blast]], SetColor(x.ActiveEnemy, "Yellow"))
					elseif s.Flashable(8092--[[Mind Blast]]) and s.BuffStack(77487--[[Shadow Orb]], "player") == 1 and x.NoCC and s.GetChanneling(15407--[[Mind Flay]], "player") <= 1 and a.Castable["Mind Blast"] () then
						s.Flash(8092--[[Mind Blast]], SetColor(x.ActiveEnemy))
					end
				end
				
				--if not s.Buff(95799--[[Empowered Shadow]], "player") then
					if s.Flashable(8092--[[Mind Blast]]) and x.NoCC and s.BuffStack(77487--[[Shadow Orb]], "player") >= 1 and s.GetChanneling(15407--[[Mind Flay]], "player") <= 1 and a.Castable["Mind Blast"] () then
						s.Flash(8092--[[Mind Blast]], SetColor(x.ActiveEnemy, "Yellow"))
					elseif s.Flashable(34914--[[Vampiric Touch]]) and x.NoCC and s.GetChanneling(15407--[[Mind Flay]], "player") <= 1 and s.MyDebuffDuration(34914--[[Vampiric Touch]], nil, 3) and a.Castable["Vampiric Touch"]() then
						s.Flash(34914--[[Vampiric Touch]], SetColor(x.ActiveEnemy))
					elseif s.Flashable(589--[[Shadow Word: Pain]]) and x.NoCC and a.Castable["Shadow Word: Pain"]() then
						s.Flash(589--[[Shadow Word: Pain]], SetColor(x.ActiveEnemy))
					elseif s.Flashable(2944--[[Devouring Plague]]) and x.NoCC and s.GetChanneling(15407--[[Mind Flay]], "player") <= 1 and a.Castable["Devouring Plague"]() then
						s.Flash(2944--[[Devouring Plague]], SetColor(x.ActiveEnemy))
					elseif s.Flashable(32379--[[Shadow Word: Death]]) and s.HasTalent(14910--[[Mind Melt]]) and x.NoCC and s.GetChanneling(15407--[[Mind Flay]], "player") <= 1 and a.Castable["Shadow Word: Death"]() then
						s.Flash(32379--[[Shadow Word: Death]], SetColor(x.ActiveEnemy, "Yellow"))
					elseif s.Flashable(15407--[[Mind Flay]]) and x.NoCC and a.Castable["Mind Flay"]() then
						s.Flash(15407--[[Mind Flay]], SetColor(x.ActiveEnemy))
					end
				--end
				
				--if not s.Buff(95799--[[Empowered Shadow]], "player") then
					
				--end
			end
end

local function HolyProc()
	if a.GetConfig("Disable_Holy") then return end
	if s.TalentMastery(2) then
		--Charka
			--Prayer of Mending or Prayer of Healing
			--Flash Heal or Heal or Greater Heal
		--Divine Hymn if Heroism
		--Serindipity
			--Greater heal or Prayer of Healing
		--Guardian Spirit
		
		end
end

local function DiscProc()
	if a.GetConfig("Disable_Disc") then return end
	if s.TalentMastery(1) then
		
	end
end

-- Use this single spam function and remove the multiple spam table below, or just use the multiple spam table below and leave this function in place.
s.Spam[AddonName] = function() if a.GetConfig("spell_flashing_off") then return end a.RunSpamTable()
	
		Buffs()
		CrowdControl()
		Survival()
		ManaRegen()
		Interrupts()
		TrashRotation()
		ShadowRotation()
		HolyProc()
		DiscProc()
		LightWell8Ball()
	
end