local AddonName, a = ...
if a.BuildFail(40000, 50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable


a.spells["Attack"] = {
	ID = 88163--[[Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = {
		88163--[[Attack]],
		6603--[[Auto Attack]],
	},
	FlashID = {
		88163--[[Attack]],
		6603--[[Auto Attack]],
	},
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Battle Stance"] = {
	Type = "form",
	ID = 2457--[[Battle Stance]],
}

a.spells["Defensive Stance"] = {
	Type = "form",
	ID = 71--[[Defensive Stance]],
}

a.spells["Berserker Stance"] = {
	Type = "form",
	ID = 2458--[[Berserker Stance]],
}

a.spells["Battle Shout"] = {
	ID = 6673--[[Battle Shout]],
	MyBuff = 469--[[Commanding Shout]],
	BuffUnit = "player",
	EarlyRefresh = 5,
	BuffUnit1 = "player",
	CheckFirst = function(z)
		if not x.ShouldTemporaryBuff or not x.EnemyDetected then
			return false
		elseif x.ActiveEnemy and s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) < 50 and ( s.NotDieing() or s.Boss() ) then
			if s.Flashable(469--[[Commanding Shout]]) and not s.MyBuff(z.ID, "player", x.DoubleLag) and s.Buff(a.StrengthAndAgilityBuffs, "player", x.DoubleLag) and not s.Buff(a.StaminaBuffs, "player", x.DoubleLag) then
				return false
			end
			z.Buff1 = nil
			z.FlashColor = "Yellow"
		else
			z.Buff1 = a.StrengthAndAgilityBuffs
			z.FlashColor = "Green"
		end
		return true
	end,
}

a.spells["Commanding Shout"] = {
	ID = 469--[[Commanding Shout]],
	MyBuff = 6673--[[Battle Shout]],
	BuffUnit = "player",
	EarlyRefresh = 5,
	BuffUnit1 = "player",
	CheckFirst = function(z)
		if not x.ShouldTemporaryBuff or not x.EnemyDetected then
			return false
		elseif x.ActiveEnemy and s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) < 50 and ( s.NotDieing() or s.Boss() ) then
			if s.Flashable(6673--[[Battle Shout]]) and not s.MyBuff(z.ID, "player", x.DoubleLag) and s.Buff(a.StaminaBuffs, "player", x.DoubleLag) and not s.Buff(a.StrengthAndAgilityBuffs, "player", x.DoubleLag) then
				return false
			end
			z.Buff1 = nil
			z.FlashColor = "Yellow"
		else
			z.Buff1 = a.StaminaBuffs
			z.FlashColor = "Green"
		end
		return true
	end,
}

a.spells["Demoralizing Shout"] = {
	ID = 1160--[[Demoralizing Shout]],
	Debuff = {
		702--[[Curse of Weakness]],
		1160--[[Demoralizing Shout]],
		99--[[Demoralizing Roar]],
		24423--[[Demoralizing Screech]],
		26016--[[Vindication]],
	},
	EnemyTargetNeeded = 1,
	NoRangeCheck = 1,
	FlashColor = "Blue",
	CheckFirst = function(z)
		return x.ActiveEnemy and CheckInteractDistance(s.UnitSelection(), 3) and ( s.NotDieing() or s.Boss() )
	end,
}

a.spells["Berserker Rage"] = {
	ID = 18499--[[Berserker Rage]],
	FlashColor = "Aqua",
	CheckFirst = function(z)
		return s.CrowedControlled("player")
	end,
}

a.spells["Berserker Rage - Raging Blow"] = {
	ID = 18499--[[Berserker Rage]],
	FlashColor = "Yellow",
	CheckFirst = function(z)
		return x.ActiveEnemy and a.Flashable("Raging Blow - Berserker Rage")
	end,
}

a.spells["Raging Blow - Berserker Rage"] = {
	ID = 85288--[[Raging Blow]],
	EnemyTargetNeeded = 1,
	EvenIfNotUsable = 1,
}

a.spells["Raging Blow"] = {
	ID = 85288--[[Raging Blow]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC
	end,
}

a.spells["Charge"] = {
	ID = 100--[[Charge]],
	EnemyTargetNeeded = 1,
	NotIfActive = {
		100--[[Charge]],
		20252--[[Intercept]],
	},
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and not a:IsTimer("Charge")
	end,
}

a.spells["Intercept"] = {
	ID = 20252--[[Intercept]],
	EnemyTargetNeeded = 1,
	NotIfActive = {
		100--[[Charge]],
		20252--[[Intercept]],
	},
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and not a:IsTimer("Charge")
	end,
}

a.spells["Cleave"] = {
	ID = 845--[[Cleave]],
	EnemyTargetNeeded = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and ( s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) >= 70 or s.BuffDuration(85730--[[Deadly Calm]], "player") > (s.SpellCooldown(z.ID) + x.Lag) )
	end,
}

a.spells["Colossus Smash"] = {
	ID = 86346--[[Colossus Smash]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Disarm"] = {
	ID = 676--[[Disarm]],
	Debuff = 676--[[Disarm]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		if not s.Player() then
			z.FlashColor = "Pink"
			return x.ActiveEnemy
		elseif s.Class(nil, a.MeleeClasses) then
			z.FlashColor = "Aqua"
			return x.ActiveEnemy
		end
		return false
	end,
}

a.spells["Enraged Regeneration"] = {
	ID = 55694--[[Enraged Regeneration]],
	FlashColor = "Red",
	CheckFirst = function(z)
		return ( s.InCombat() or s.EnemyTargetingYou("focus") or s.EnemyTargetingYou("enemy") ) and s.HealthPercent("player") <= 45
	end,
}

a.spells["Execute"] = {
	ID = 5308--[[Execute]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC
	end,
}

a.spells["Hamstring"] = {
	ID = 1715--[[Hamstring]],
	Debuff = 1715--[[Hamstring]],
	EarlyRefresh = 2,
	EnemyTargetNeeded = 1,
	FlashColor = "Yellow",
	CheckFirst = function(z)
		return x.ActiveEnemy and ( s.Player() or ( not UnitExists(s.UnitSelection().."target") and not s.Boss() ) )
	end,
}

a.spells["Heroic Strike - Shield Slam"] = {
	ID = 78--[[Heroic Strike]],
	EnemyTargetNeeded = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC and s.SpellCooldown(23922--[[Shield Slam]]) > s.SpellCooldown(z.ID) and ( s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) >= 70 or s.BuffDuration(85730--[[Deadly Calm]], "player") > s.SpellCooldown(z.ID) + x.Lag )
	end,
}

a.spells["Heroic Strike"] = {
	ID = 78--[[Heroic Strike]],
	EnemyTargetNeeded = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC and ( s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) >= 70 or s.BuffDuration(85730--[[Deadly Calm]], "player") > s.SpellCooldown(z.ID) + x.Lag )
	end,
}

a.spells["Heroic Throw"] = {
	ID = 57755--[[Heroic Throw]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and not s.MeleeDistance()
	end,
}

a.spells["Inner Rage"] = {
	ID = 1134--[[Inner Rage]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	FlashColor = "Green",
	CheckFirst = function(z)
		return x.ActiveEnemy and s.SpellCooldown(78--[[Heroic Strike]]) > x.Lag
	end,
}

a.spells["Intervene"] = {
	ID = 3411--[[Intervene]],
	CheckFirst = function(z)
		z.FlashColor = s.If(s.ActiveEnemy(s.UnitSelection().."target") and UnitIsUnit(s.UnitSelection().."targettarget", s.UnitSelection()), "White", "Pink")
		return UnitIsFriend("player", s.UnitSelection())
	end,
}

a.spells["Overpower"] = {
	ID = 7384--[[Overpower]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC
	end,
}

a.spells["Pummel"] = {
	ID = 6552--[[Pummel]],
	EnemyTargetNeeded = 1,
	Interrupt = 1,
	Run = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Aqua", "Pink")
	end,
}

a.spells["Recklessness"] = {
	ID = 1719--[[Recklessness]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	FlashColor = "Pink",
	CheckFirst = function(z)
		return x.ActiveEnemy and s.InCombat() and not s.EnemyTargetingYou("focus") and not s.EnemyTargetingYou("enemy") and ( s.NotDieing() or s.Boss() )
	end,
}

a.spells["Rend - Blood and Thunder"] = {
	ID = 772--[[Rend]],
	MyDebuff = 772--[[Rend]],
	EarlyRefresh = 1,
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and s.HasTalent(84614--[[Blood and Thunder]])
	end,
}

a.spells["Rend - Blood"] = {
	ID = 772--[[Rend]],
	MyDebuff = 772--[[Rend]],
	EarlyRefresh = 1,
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC and ( s.HasTalent(56636--[[Taste for Blood]]) or s.HasTalent(29836--[[Blood Frenzy]]) )
	end,
}

a.spells["Rend"] = {
	ID = 772--[[Rend]],
	MyDebuff = 772--[[Rend]],
	EarlyRefresh = 1,
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and ( s.NotDieing() or s.Boss() )
	end,
}

a.spells["Retaliation"] = {
	ID = 20230--[[Retaliation]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	FlashColor = "Pink",
	CheckFirst = function(z)
		return x.ActiveEnemy and s.InCombat() and s.EnemyTargetingYou() and ( s.NotDieing() or s.Boss() )
	end,
}

a.spells["Revenge"] = {
	ID = 6572--[[Revenge]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC
	end,
}

a.spells["Shattering Throw"] = {
	ID = 64382--[[Shattering Throw]],
	EnemyTargetNeeded = 1,
	FlashColor = "Pink",
	CheckFirst = function(z)
		return x.ActiveEnemy
	end,
}

a.spells["Shield Bash"] = {
	ID = 72--[[Shield Bash]],
	EnemyTargetNeeded = 1,
	Interrupt = 1,
	Run = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Aqua", "Pink")
	end,
}

a.spells["Shield Block - Heavy Repercussions"] = {
	ID = 2565--[[Shield Block]],
	Buff = 2565--[[Shield Block]],
	BuffUnit = "player",
	Melee = 1,
	FlashColor = "Yellow",
	CheckFirst = function(z)
		if not x.ActiveEnemy or not s.HasTalent(86894--[[Heavy Repercussions]]) then return false end
		local SpellName = 23922--[[Shield Slam]]
		local cooldown, duration = s.SpellCooldown(SpellName)
		return cooldown <= s.SpellCooldown(z.ID) + x.DoubleLag and ( s.BuffDuration(85730--[[Deadly Calm]], "player") > 1.5 + x.DoubleLag or s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) >= s.SpellCost(z.ID) + s.SpellCost(SpellName) )
	end,
}

a.spells["Shield Block"] = {
	ID = 2565--[[Shield Block]],
	Buff = 2565--[[Shield Block]],
	BuffUnit = "player",
	Melee = 1,
	FlashColor = "Pink",
	CheckFirst = function(z)
		if not x.ActiveEnemy or s.HasTalent(86894--[[Heavy Repercussions]]) then return false end
		if not s.EnemyTargetingYou("focus") and not s.EnemyTargetingYou("enemy") then
			return false
		end
		local SpellName = 6572--[[Revenge]]
		local cooldown, duration = s.SpellCooldown(SpellName)
		return cooldown <= s.SpellCooldown(z.ID) + x.DoubleLag and ( s.BuffDuration(85730--[[Deadly Calm]], "player") > 1.5 + x.DoubleLag or s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) >= s.SpellCost(z.ID) + s.SpellCost(SpellName) )
	end,
}

a.spells["Shield Wall"] = {
	ID = 871--[[Shield Wall]],
	EnemyTargetNeeded = 1,
	FlashColor = "Red",
	CheckFirst = function(z)
		return ( s.InCombat() or s.EnemyTargetingYou("focus") or s.EnemyTargetingYou("enemy") ) and s.HealthPercent("player") <= 35
	end,
}

a.spells["Slam - Bloodsurge"] = {
	ID = 1464--[[Slam]],
	RequireBuff = 46916--[[Bloodsurge]],
	RequireBuffUnit = "player",
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC and s.HasTalent(46913--[[Bloodsurge]]) and s.SpellCooldown(78--[[Heroic Strike]]) > x.Lag and ( s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) >= 70 or s.BuffDuration(85730--[[Deadly Calm]], "player") > (s.SpellCooldown(z.ID) + x.Lag) )
	end,
}

a.spells["Slam"] = {
	ID = 1464--[[Slam]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and s.SpellCooldown(78--[[Heroic Strike]]) > x.Lag and ( s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) >= 70 or s.BuffDuration(85730--[[Deadly Calm]], "player") > (s.SpellCooldown(z.ID) + x.Lag) )
	end,
}

a.spells["Spell Reflection"] = {
	ID = 23920--[[Spell Reflection]],
	EnemyTargetNeeded = 1,
	FlashColor = "Aqua",
	CheckFirst = function(z)
		return ( s.EnemyTargetingYou("focus") and s.GetCasting(nil, "focus") > s.SpellCooldown(z.ID) + x.DoubleLag ) or ( s.EnemyTargetingYou("enemy") and s.GetCasting(nil, "enemy") > (s.SpellCooldown(z.ID) + x.DoubleLag) )
	end,
}

a.spells["Strike"] = {
	ID = 88161--[[Strike]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and not s.TalentMastery()
	end,
}

a.spells["Sunder Armor"] = {
	ID = 7386--[[Sunder Armor]],
	Debuff = {
		7386--[[Sunder Armor]],
		91565--[[Faerie Fire]],
	},
	Stack = 3,
	EarlyRefresh = 10,
	EnemyTargetNeeded = 1,
	FlashColor = "Pink",
	CheckFirst = function(z)
		return x.ActiveEnemy and not s.HasSpell(20243--[[Devastate]])
	end,
}

a.spells["Taunt"] = {
	ID = 355--[[Taunt]],
	FlashColor = "Pink",
	CheckFirst = function(z)
		local ThreatTarget = s.GetPrimaryThreatTarget()
		return ThreatTarget and not UnitIsUnit(ThreatTarget, "player") and s.EnemyTargetingYourFriend()
	end,
}

a.spells["Thunder Clap"] = {
	ID = 6343--[[Thunder Clap]],
	Debuff = a.HasteDebuffs,
	NoRangeCheck = 1,
	EnemyTargetNeeded = 1,
	Melee = 1,
	FlashColor = "Blue",
	CheckFirst = function(z)
		return x.ActiveEnemy
	end,
}

a.spells["Thunder Clap - AOE"] = {
	ID = 6343--[[Thunder Clap]],
	NoRangeCheck = 1,
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Victory Rush"] = {
	ID = 34428--[[Victory Rush]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC
	end,
}

a.spells["Whirlwind"] = {
	ID = 1680--[[Whirlwind]],
	NoRangeCheck = 1,
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Bloodthirst"] = {
	ID = 23881--[[Bloodthirst]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Mortal Strike - Lambs to the Slaughter"] = {
	ID = 12294--[[Mortal Strike]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and s.HasTalent(84583--[[Lambs to the Slaughter]])
	end,
}

a.spells["Mortal Strike"] = {
	ID = 12294--[[Mortal Strike]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Shield Slam - Heavy Repercussions"] = {
	ID = 23922--[[Shield Slam]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Yellow", "Pink")
		return x.NoCC and s.HasTalent(86894--[[Heavy Repercussions]]) and ( s.CurrentSpell(2565--[[Shield Block]]) or s.SpellDelay(2565--[[Shield Block]]) or s.Buff(2565--[[Shield Block]], "player") )
	end,
}

a.spells["Shield Slam"] = {
	ID = 23922--[[Shield Slam]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Bladestorm"] = {
	ID = 46924--[[Bladestorm]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Concussion Blow"] = {
	ID = 12809--[[Concussion Blow]],
	EnemyTargetNeeded = 1,
	Interrupt = 1,
	Run = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Aqua", "Pink")
	end,
}

a.spells["Deadly Calm"] = {
	ID = 85730--[[Deadly Calm]],
	EnemyTargetNeeded = 1,
	FlashColor = "Green",
	CheckFirst = function(z)
		return x.ActiveEnemy and s.InCombat() and s.Power("player") - s.SpellCost(s.CastingName(nil, "player"), SPELL_POWER_RAGE) < 50 and ( s.NotDieing() or s.Boss() )
	end,
}

a.spells["Death Wish"] = {
	ID = 12292--[[Death Wish]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	FlashColor = "Green",
	CheckFirst = function(z)
		return x.ActiveEnemy and s.InCombat() and ( s.NotDieing() or s.Boss() )
	end,
}

a.spells["Devastate"] = {
	ID = 20243--[[Devastate]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Heroic Fury"] = {
	ID = 60970--[[Heroic Fury]],
	EnemyTargetNeeded = 1,
	FlashColor = "Aqua",
	CheckFirst = function(z)
		return s.Rooted("player")
	end,
}

a.spells["Last Stand"] = {
	ID = 12975--[[Last Stand]],
	EnemyTargetNeeded = 1,
	FlashColor = "Red",
	CheckFirst = function(z)
		return ( s.InCombat() or s.EnemyTargetingYou("focus") or s.EnemyTargetingYou("enemy") ) and s.HealthPercent("player") <= 10
	end,
}

a.spells["Piercing Howl"] = {
	ID = 12323--[[Piercing Howl]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return CheckInteractDistance(s.UnitSelection(), 3)
	end,
}

a.spells["Shockwave"] = {
	ID = 46968--[[Shockwave]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and CheckInteractDistance(s.UnitSelection(), 3)
	end,
}

a.spells["Sweeping Strikes"] = {
	ID = 12328--[[Sweeping Strikes]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Throwdown"] = {
	ID = 85388--[[Throwdown]],
	EnemyTargetNeeded = 1,
	Interrupt = 1,
	Run = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Aqua", "Pink")
	end,
}

